"""
Provide a dataset for pytorch training
Can instantiate with a personnal dataset (X,y) or a register one
"""
